BioPAX object model
-------------------

.. automodule:: pybiopax.biopax
    :members:
    :show-inheritance:
    :inherited-members:

.. automodule:: pybiopax.biopax.model
    :members:
    :show-inheritance:
    :inherited-members:

Base classes
~~~~~~~~~~~~

.. automodule:: pybiopax.biopax.base
    :members:
    :show-inheritance:
    :inherited-members:

Interactions
~~~~~~~~~~~~

.. automodule:: pybiopax.biopax.interaction
    :members:
    :show-inheritance:
    :inherited-members:

Physical entities
~~~~~~~~~~~~~~~~~

.. automodule:: pybiopax.biopax.physical_entity
    :members:
    :show-inheritance:
    :inherited-members:

Utility classes
~~~~~~~~~~~~~~~

.. automodule:: pybiopax.biopax.util
    :members:
    :show-inheritance:
    :inherited-members:
